#ifndef KEYS_H
#define KEYS_H

#include <QtGui>

namespace Ui {
    class keys;
    class sh_key;
}

class sh_key : public QLineEdit
{
    Q_OBJECT

public:
    explicit sh_key(QWidget *parent = 0);

protected:
    void keyPressEvent ( QKeyEvent * event ) ;


};


class keys : public QWidget
{
    Q_OBJECT

public:
    explicit keys(QWidget *parent = 0, QString filename="", QString name="");
    ~keys();
    static int keysConfigCount();
    static QString defaultFile();
    static QHash<QString, QString> configList();

private:
    sh_key *nkey[24];
    QStringList ks;
    QString m_Filename;
    QString m_Name;

private slots:
    void save();

protected:
    void hideEvent(QHideEvent *);

};

#endif // KEYS_H
